Module action

Module action 

Keyboard actions and behaviors.

This module defines the core action system used in RMK firmware. Actions represent what happens when a key is pressed, from simple key presses to complex behaviors like tap-hold, layer switching, and macros.

Key types:

Structs

EncoderAction
Action for a rotary encoder position, stored in the encoder map.

Enums

Action
A single basic action that a keyboard can execute.
KeyAction
A KeyAction is the action at a keyboard position, stored in keymap. It can be a single action like triggering a key, or a composite keyboard action like tap/hold
KeyboardAction
Actions for controlling the keyboard or changing the keyboard’s state, for example, enable/disable a particular function
LightAction
Actions for controlling lights