KeyAction

Enum KeyAction 

#[non_exhaustive]
pub enum KeyAction { No, Transparent, Single(Action), Tap(Action), TapHold(Action, Action, u8), Morse(u8), }
A KeyAction is the action at a keyboard position, stored in keymap. It can be a single action like triggering a key, or a composite keyboard action like tap/hold

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


No

No action



Transparent

Transparent action, next layer will be checked



Single(Action)

A single action, such as triggering a key, or activating a layer. Action is triggered when pressed and cancelled when released.



Tap(Action)

Don’t wait the release of the key, auto-release after a time threshold.



TapHold(Action, Action, u8)

Tap hold action. The u8 indexes the morse profile table; an index with no table entry (e.g. u8::MAX, which the default-profile macros emit) falls back to the default crate::morse::MorseProfile.



Morse(u8)

Morse action, references a morse configuration by index.

Implementations

Source

impl KeyAction

pub fn to_action(self) -> Action

Convert KeyAction to the internal Action. Only valid for Single and Tap variant, returns Action::No for other variants.

pub fn is_morse(&self) -> bool

‘morse’ is an alias for the superset of tap dance and tap hold keys, since their handling have many similarities

pub fn is_empty(&self) -> bool