MorseMode

Enum MorseMode 

#[repr(u8)]
pub enum MorseMode { PermissiveHold = 0, HoldOnOtherPress = 1, Normal = 2, }
Mode for morse key behavior

Variants



PermissiveHold = 0

Same as QMK’s permissive hold: https://docs.qmk.fm/tap_hold#tap-or-hold-decision-modes When another key is pressed and released during the current morse key is held, the hold action of current morse key will be triggered



HoldOnOtherPress = 1

Trigger hold immediately if any other non-morse key is pressed when the current morse key is held



Normal = 2

Normal mode, the decision is made when timeout