Module keycode

Module keycode 

Keycode definitions including HID keycodes, media keys, and system control keycodes.

Enums

ConsumerKey
Keys in consumer page Ref: https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf#page=75
HidKeyCode
KeyCode
SpecialKey
Key codes which are not in the HID spec, but still commonly used
SystemControlKey
Keys in Generic Desktop Page, generally used for system control Ref: https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf#page=26

Functions

from_ascii
Convert a ascii chat to keycode bool, if the keycode should be shifted assumes en-us keyboard mapping
to_ascii
Convert a ascii chat to keycode assumes en-us keyboard mapping