ConsumerKey

Enum ConsumerKey 

#[non_exhaustive]
pub enum ConsumerKey {
Show 52 variants No, SnapShot, BrightnessUp, BrightnessDown, Play, Pause, Record, FastForward, Rewind, NextTrack, PrevTrack, StopPlay, Eject, RandomPlay, Repeat, StopEject, PlayPause, Mute, VolumeIncrement, VolumeDecrement, Reserved, Email, Calculator, LocalBrowser, Lock, ControlPanel, Assistant, New, Open, Close, Exit, Maximize, Minimize, Save, Print, Properties, Undo, Copy, Cut, Paste, SelectAll, Find, Search, Home, Back, Forward, Stop, Refresh, Bookmarks, NextKeyboardLayoutSelect, DesktopShowAllWindows, AcSoftKeyLeft,
}
Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


No



SnapShot



BrightnessUp



BrightnessDown



Play



Pause



Record



FastForward



Rewind



NextTrack



PrevTrack



StopPlay



Eject



RandomPlay



Repeat



StopEject



PlayPause



Mute



VolumeIncrement



VolumeDecrement



Reserved



Email



Calculator



LocalBrowser



Lock



ControlPanel



Assistant



New



Open



Close



Exit



Maximize



Minimize



Save



Print



Properties



Undo



Copy



Cut



Paste



SelectAll



Find



Search



Home



Back



Forward



Stop



Refresh



Bookmarks



NextKeyboardLayoutSelect



DesktopShowAllWindows



AcSoftKeyLeft

Implementations

Source

impl ConsumerKey

pub fn to_hid_keycode(&self) -> Option<HidKeyCode>

Convert ConsumerKey to the corresponding HidKeyCode