pub fn from_ascii(ascii: u8) -> (HidKeyCode, bool)Expand description
Convert a ascii chat to keycode bool, if the keycode should be shifted assumes en-us keyboard mapping
pub fn from_ascii(ascii: u8) -> (HidKeyCode, bool)Convert a ascii chat to keycode bool, if the keycode should be shifted assumes en-us keyboard mapping