MorsePattern

Struct MorsePattern 

pub struct MorsePattern(/* private fields */);
MorsePattern is a sequence of maximum 15 taps or holds that can be encoded into an u16: 0x1 when empty, then 0 for tap or 1 for hold shifted from the right

Implementations

Source

impl MorsePattern

pub fn max_taps() -> usize

pub fn from_u16(value: u16) -> Self

Creates a MorsePattern from a raw u16.

Panics (debug only)

Panics if value is 0, which is not a valid encoding (the empty pattern is 0b1).

pub fn to_u16(&self) -> u16

pub fn is_empty(&self) -> bool

pub fn is_full(&self) -> bool

pub fn pattern_length(&self) -> usize

pub fn starts_with(&self, pattern_start: MorsePattern) -> bool

Checks if this pattern starts with the given one

pub fn last_is_hold(&self) -> bool

Returns true if the last step in the pattern is a hold. Returns false for empty patterns.

pub fn followed_by_tap(&self) -> Self

pub fn followed_by_hold(&self) -> Self

pub fn is_all_taps(&self) -> bool

true when the pattern consists only of tap steps (no holds). Returns false for the empty pattern (encoding 0b1).