pub struct MorseProfile(/* private fields */);Expand description
Configuration for morse, tap dance and tap-hold to save some RAM space, manually packed into 32 bits
Implementations
Sourceimpl MorseProfile
impl MorseProfile
pub const fn const_default() -> Self
Sourcepub fn unilateral_tap(self) -> Option<bool>
pub fn unilateral_tap(self) -> Option<bool>
If the previous key is on the same “hand”, the current key will be determined as a tap
pub const fn with_unilateral_tap(self, b: Option<bool>) -> Self
Sourcepub fn mode(self) -> Option<MorseMode>
pub fn mode(self) -> Option<MorseMode>
The decision mode of the morse/tap-hold key
- If neither of them is set, the decision is made when timeout
- If permissive_hold is set, same as QMK’s permissive hold: When another key is pressed and released while the current morse key is held, the hold action of current morse key will be triggered https://docs.qmk.fm/tap_hold#tap-or-hold-decision-modes
- if hold_on_other_press is set - triggers hold immediately if any other non-morse key is pressed while the current morse key is held
pub const fn with_mode(self, m: Option<MorseMode>) -> Self
Sourcepub fn hold_timeout_ms(self) -> Option<u16>
pub fn hold_timeout_ms(self) -> Option<u16>
If the key is pressed longer than this, it is accepted as hold (in milliseconds)
if given, should not be zero
pub const fn with_hold_timeout_ms(self, t: Option<u16>) -> Self
pub const fn set_hold_timeout_ms(&mut self, t: u16)
pub const fn set_gap_timeout_ms(&mut self, t: u16)
Sourcepub fn gap_timeout_ms(self) -> Option<u16>
pub fn gap_timeout_ms(self) -> Option<u16>
The time elapsed from the last release of a key is longer than this, it will break the morse pattern (in milliseconds) if given, should not be zero
pub const fn with_gap_timeout_ms(self, t: Option<u16>) -> Self
pub const fn new( unilateral_tap: Option<bool>, mode: Option<MorseMode>, hold_timeout_ms: Option<u16>, gap_timeout_ms: Option<u16>, ) -> Self