Keycode definitions including HID keycodes, media keys, and system control keycodes.
Enums
- Consumer
Key - Keys in consumer page Ref: https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf#page=75
- HidKey
Code - KeyCode
- Special
Key - Key codes which are not in the HID spec, but still commonly used
- System
Control Key - Keys in
Generic Desktop Page, generally used for system control Ref: https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf#page=26
Functions
- from_
ascii - Convert a ascii chat to keycode bool, if the keycode should be shifted assumes en-us keyboard mapping
- to_
ascii - Convert a ascii chat to keycode assumes en-us keyboard mapping